/*
 * Arduino code for microstepper-project DDS-board
 * AW2021-09, see https://ohwr.org/project/microstepper
 * 
*/

#ifndef __ADF4350_H__
#define __ADF4350_H__

namespace ADF4350 {
  
// ADF4350 register addresses
// https://www.analog.com/media/en/technical-documentation/data-sheets/ADF4350.pdf
  
// Control Bits. Determines destination register
// Datasheet page 14/34
const int R0 = 0b000; // Resister 0 (R0), 1-reserved, 16-bit integer N, 12-bit fractional (FRAC), 3 control bits
const int R1 = 0b001; // Register 1 (R1), 4-reserved, 1-prescaler, 12-phase, 12-modulus (MOD), 3-control
const int R2 = 0b010; // Register 2 (R2), DB31:DB23 reserved, DB22 feedback select, DB22:DB20 Divider select
const int R3 = 0b011; // Resister 3 (R3)
const int R4 = 0b100; // Register 4 (R4)
const int R5 = 0b101; // Register 5 (R5)

//Register 0


// 10MHz ref in 1GHz out operation preset
// Send directly to PLL in descending order (R5 -> R0)

// old settings from 2014
//const int32_t preset1_R0 = 0x00C80000;
//const int32_t preset1_R1 = 0x08008009;
//const int32_t preset1_R2 = 0x00004E42;
//const int32_t preset1_R3 = 0x000004B3;
//const int32_t preset1_R4 = 0x00A5003C;
//const int32_t preset1_R5 = 0x00058005;

// new settings, using ADF435x Software, 2021
// Both output-A and output-B enabled, 10MHz ref, A and B both 1 GHz.
// register-values from Evaluation Software Rev 4.5.0
// https://www.analog.com/en/design-center/evaluation-hardware-and-software/evaluation-boards-kits/EVAL-ADF4350.html
const int32_t preset1_R0 = 0x01900000;
const int32_t preset1_R1 = 0x08008011;
const int32_t preset1_R2 = 0x14020E42;
const int32_t preset1_R3 = 0x000004B3;
const int32_t preset1_R4 = 0x0020A1FC;
const int32_t preset1_R5 = 0x00580005;


// 100MHz ref in 1GHz out operation preset
// Send directly to PLL in descending order (R5 -> R0)

const int32_t preset2_R0 = 0x00500000;
const int32_t preset2_R1 = 0x08008009;
const int32_t preset2_R2 = 0x01008E42;
const int32_t preset2_R3 = 0x000004B3;
const int32_t preset2_R4 = 0x00AC803C;
const int32_t preset2_R5 = 0x00058005;


} // end namespace
#endif 
