"""
    This file is part of the Microstepper project
    https://www.ohwr.org/project/microstepper
    
    This simple script computes microstepper output frequency
    given DDS frequency tuning words.
    
    released under GPLv3 or later license.
    Anders Wallin, 2019-2020
"""
import bigfloat
import numpy
import requests
import time

import ustep

def ftw_dds(f_hz):
    """ return AD9912 1GHz SYSCLK FTW
    """
    return numpy.round(f_hz*ftw_length/dds_clk,0)

def hz_dds(ftw):
    """ return f_out [Hz]
    """
    return dds_clk*ftw/ftw_length

def split_hex(ftw):
    out=[]
    for n in range(6):
        hexdigits = (ftw & (mask << n*8) )  >> n*8 
        print("%x " % hexdigits)
        out.append(hexdigits)
    return out
    
    
dds_clk=1.0e9
ftw_length = pow(2,48)


# nominally we get zero output frequency with these 
# tuning-wrods:
FTW1 =  0x004189374bc6
mask = 0x0000000000ff
#FTW1 = 0x004289374bc6
f_hz_1 = hz_dds(FTW1)
print("0x%012x \t %.9f" % (FTW1, f_hz_1))

f1 = hz_dds(FTW1)

print( ["%02x"%dig for dig in split_hex(FTW1)], " ", "%.12f"%f1 )

for n in range(1):
    f = 123e6+2e6*n
    FTW1 = ustep.ftw_dds( f ) 
    hexs = split_hex(FTW1)
    ftw_string = "%02x:%02x:%02x:%02x:%02x:%02x" % (hexs[5],hexs[4],hexs[3],hexs[2],hexs[1],hexs[0] )
    r = requests.get('http://192.168.1.18/DDS:A:FTW:%s' % ftw_string)
    print("%.6f %s" % (f, ftw_string))
    time.sleep(1)
    
