"""
    This file is part of the Microstepper project
    https://www.ohwr.org/project/microstepper
    
    This simple script computes microstepper output frequency
    given DDS frequency tuning words.
    
    released under GPLv3 or later license.
    Anders Wallin, 2019-2020
"""
import matplotlib.pyplot as plt
import numpy

import ustep


# nominal F1
F1 = 112535015102874
F2 = 112589990683444

y, y18 = ustep.y_out(F1, F2)

print( ["%02x"%x for x in ustep.split_hex(F1)])

print(y18)
yset = numpy.linspace(-100, 100, 400)
#print(yset)
y18s = []
fs = []
for y in yset:
    ftw2 = ustep.f2_from_y( y, F1 )
    _, y18 = ustep.y_out( F1, ftw2 )
    y18s.append(y18)
    fs.append(ftw2)
    
plt.figure()
fs = numpy.array(fs)
plt.plot(yset, yset, 'r-', label='Ideal')
plt.plot(yset, y18s, '.', label='uStepper')

plt.plot(yset, y18s-yset, 'm.', label='Error')
plt.xlabel('set-point / y18')
plt.ylabel('output / y18')
plt.legend()
plt.grid()
plt.show()
